@@ -1,4 +1,6 @@
-{package POEx::Role::SessionInstantiation::Meta::Session::Sugar;}
+{package POEx::Role::SessionInstantiation::Meta::Session::Sugar;
+our $VERSION = '0.092671';}
+
 
 #ABSTRACT: Provides some convenience methods for some POE::Kernel methods
 
@@ -39,7 +41,7 @@ POEx::Role::SessionInstantiation::Meta::Session::Sugar - Provides some convenien
 
 =head1 VERSION
 
-version 0.092670
+version 0.092671
 
 =head1 METHODS
 
